# AeroMesh

**AeroMesh** is a wind farm mesher that makes generating finite elements meshes easy. It can accept farm specifications
from either a properly formatted YAML file or from an external API call made by another process. It currently supports refinement specifications
at the domain, farm, and turbine level in both two and three dimensions.